.. _tutorial_main:

=========
Tutorials
=========

Here you'll find a set of tutorials that provide step-by-step instructions for common tasks
using the ``pseudopeople`` package.


.. toctree::
   :maxdepth: 1
   :glob:

   *